pub struct PackTransformFlags {
pub encrypt: bool,
pub train_dict: bool,
pub parallel: bool,
}Expand description
Configuration parameters for archive packing.
This struct encapsulates all settings for the packing process. It’s designed to be easily constructed from CLI arguments or programmatic APIs.
Examples
use hexz_ops::pack::PackConfig;
use std::path::PathBuf;
// Basic configuration with defaults
let config = PackConfig {
input: PathBuf::from("data/"),
output: PathBuf::from("archive.hxz"),
..Default::default()
};
// Advanced configuration with CDC and encryption
let advanced = PackConfig {
input: PathBuf::from("data/"),
output: PathBuf::from("archive.hxz"),
compression: "zstd".to_string(),
password: Some("secret".to_string()),
min_chunk: Some(16384),
avg_chunk: Some(65536),
max_chunk: Some(131072),
transform: hexz_ops::pack::PackTransformFlags { encrypt: true, ..Default::default() },
..Default::default()
};Feature flags controlling how data is transformed during packing.
Fields
encrypt: boolEnable encryption.
train_dict: boolTrain a compression dictionary (zstd only).
parallel: boolEnable parallel compression (use multiple CPU cores).