Module predict

Module predict 

Pre-pack analysis and savings prediction.

Structs

PredictConfig
Configuration for the predict command.
PredictReport
Results from analyzing a raw file for hexz packing potential.

Functions

predict
Analyze a raw data file and estimate hexz packing savings.