pub fn predict(config: &PredictConfig) -> Result<PredictReport>Expand description
Analyze a raw data file and estimate hexz packing savings.
pub fn predict(config: &PredictConfig) -> Result<PredictReport>Analyze a raw data file and estimate hexz packing savings.