Pre-pack analysis and savings prediction.
Structs
- Predict
Config - Configuration for the predict command.
- Predict
Report - Results from analyzing a raw file for hexz packing potential.
Functions
- predict
- Analyze a raw data file and estimate hexz packing savings.